@@ -25,8 +25,10 @@ from .ml_sentence_splitter import MLSentenceSplitterMixin
 from .ml_template import MLTemplatesMixin
 from .ml_user_feedback import MLUserFeedbackMixin
 from .objects import ObjectsMixin
+from .pipeline_sections import PipelineSectionsMixin
 from .pipeline_status import PipelineStatusMixin
 from .pipeline_workflows import PipelineWorkflowMixin
+from .project_translations import ProjectTranslationsMixin
 from .projects import ProjectsMixin
 from .savedsearches import SavedSearchesMixin
 from .smartfilters import SmartfiltersMixin
@@ -1594,9 +1596,11 @@ class TopicApiMixin(
     GlobalTempMixin,
     MachineLearningMixin,
     ObjectsMixin,
+    PipelineSectionsMixin,
     PipelineStatusMixin,
     PipelineWorkflowMixin,
     ProjectGuideFilesMixin,
+    ProjectTranslationsMixin,
     ProjectsMixin,
     SavedSearchesMixin,
     SmartfiltersMixin,
