@@ -1,11 +1,5 @@
 # TODO: remove this file completely
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
-
-from builtins import object
 
 from ..util import deprecation
 
